==> spotify_openapi-0.0.0.tar.gz: test/device_object_test.dart <==
import 'package:test/test.dart';
import 'package:spotify_openapi/spotify_openapi.dart';

// tests for DeviceObject
void main() {
  final DeviceObject? instance = /* DeviceObject(...) */ null;
  // TODO add properties to the entity

  group(DeviceObject, () {
    // The device ID.
    // String id
    test('to test the property `id`', () async {
      // TODO
    });

    // If this device is the currently active device.
    // bool isActive
    test('to test the property `isActive`', () async {
      // TODO
    });

    // If this device is currently in a private session.
    // bool isPrivateSession
    test('to test the property `isPrivateSession`', () async {
      // TODO
    });

    // Whether controlling this device is restricted. At present if this is \"true\" then no Web API commands will be accepted by this device.
    // bool isRestricted
    test('to test the property `isRestricted`', () async {
      // TODO
    });

    // A human-readable name for the device. Some devices have a name that the user can configure (e.g. \\\"Loudest speaker\\\") and some devices have a generic name associated with the manufacturer or device model.
    // String name
    test('to test the property `name`', () async {
      // TODO
    });

    // Device type, such as \"computer\", \"smartphone\" or \"speaker\".
    // String type
    test('to test the property `type`', () async {
      // TODO
    });

    // The current volume in percent.
    // int volumePercent
    test('to test the property `volumePercent`', () async {
      // TODO
    });

  });
}

==> spotify_openapi-0.0.1.tar.gz: test/device_object_test.dart <==
import 'package:test/test.dart';
import 'package:spotify_openapi/spotify_openapi.dart';

// tests for DeviceObject
void main() {
  //final instance = DeviceObjectBuilder();
  // TODO add properties to the builder and call build()

  group(DeviceObject, () {
    // The device ID.
    // String id
    test('to test the property `id`', () async {
      // TODO
    });

    // If this device is the currently active device.
    // bool isActive
    test('to test the property `isActive`', () async {
      // TODO
    });

    // If this device is currently in a private session.
    // bool isPrivateSession
    test('to test the property `isPrivateSession`', () async {
      // TODO
    });

    // Whether controlling this device is restricted. At present if this is \"true\" then no Web API commands will be accepted by this device.
    // bool isRestricted
    test('to test the property `isRestricted`', () async {
      // TODO
    });

    // A human-readable name for the device. Some devices have a name that the user can configure (e.g. \\\"Loudest speaker\\\") and some devices have a generic name associated with the manufacturer or device model.
    // String name
    test('to test the property `name`', () async {
      // TODO
    });

    // Device type, such as \"computer\", \"smartphone\" or \"speaker\".
    // String type
    test('to test the property `type`', () async {
      // TODO
    });

    // The current volume in percent.
    // int volumePercent
    test('to test the property `volumePercent`', () async {
      // TODO
    });

  });
}
